@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2008 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2009 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -18,9 +18,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
- */
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */ 
 
 #ifndef CHEROKEE_COMMON_INTERNAL_H
 #define CHEROKEE_COMMON_INTERNAL_H
@@ -34,6 +34,7 @@
 #endif
 
 #include "common.h"
+#include "threading.h"
 
 #ifndef _WIN32
 # if defined HAVE_ENDIAN_H
@@ -42,6 +43,8 @@
 #  include <machine/endian.h>
 # elif defined HAVE_SYS_ENDIAN_H
 #  include <sys/endian.h>
+# elif defined HAVE_SYS_MACHINE_H
+#  include <sys/machine.h>
 # elif defined HAVE_SYS_ISA_DEFS_H
 #  include <sys/isa_defs.h>
 # else
