@@ -736,10 +736,13 @@ cherokee_connection_build_header (cherokee_connection_t *conn)
 		}
 	}
 
-	/* handler::add_headers() might have activated the
-	 * conn_op_cant_encoder bit. If so, a encoder cannot be used
+	/* Instance an encoder if needed. Special-case: the proxy
+	 * handler might have instanced a encoded at this stage.
 	 */
-	if (conn->encoder_new_func) {
+	if ((conn->encoder == NULL) &&
+	    (conn->encoder_new_func))
+	{
+		/* Internally checks conn_op_cant_encoder */
 		cherokee_connection_instance_encoder (conn);
 	}
 
@@ -1098,6 +1101,9 @@ out:
 int
 cherokee_connection_should_include_length (cherokee_connection_t *conn)
 {
+	if (conn->encoder_new_func) {
+		return false;
+	}
 	if (conn->encoder) {
 		return false;
 	}
@@ -1111,19 +1117,33 @@ cherokee_connection_instance_encoder (cherokee_connection_t *conn)
 {
 	ret_t ret;
 
+	/* Ensure that the content can be encoded
+	 */
 	if (conn->options & conn_op_cant_encoder)
 		return ret_deny;
 
+	if (! http_type_200 (conn->error_code))
+		return ret_deny;
+
+	/* Instance and initialize the encoder
+	 */
 	ret = conn->encoder_new_func ((void **)&conn->encoder);
 	if (unlikely (ret != ret_ok))
-		return ret_error;
+		goto error;
 		
 	ret = cherokee_encoder_init (conn->encoder, conn);
 	if (unlikely (ret != ret_ok))
-		return ret_error;
+		goto error;
 	
 	cherokee_buffer_clean (&conn->encoder_buffer);
 	return ret_ok;
+
+error:
+	if (conn->encoder) {
+		cherokee_encoder_free (conn->encoder);
+		conn->encoder = NULL;
+	}
+	return ret_error;
 }
 
 
