@@ -13,7 +13,7 @@ vserver!0440!user_dir!rule!1!handler = common
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name = "Invalid home"
 
         self.request          = "GET /~missing/file HTTP/1.1\r\n" + \
